@@ -362,13 +362,14 @@ class ExcelRenderer:
     ROW_START = 3
     global res
     res = ''
-    def __init__(self, analysis_run, tenantId):
+    def __init__(self, analysis_run, tenantId, integrationId):
         """
         :param analysis_run: AnalysisRun
         """
         self.wb = Workbook()
         self.analysis_run = analysis_run
-        #self.tenantId = tenantId
+        self.integrationId = integrationId
+        self.tenantId = tenantId
         
         def get_token():
             headers = {"Content-Type" : "application/x-www-form-urlencoded" , "Accept" : "application/json"};
@@ -412,45 +413,12 @@ class ExcelRenderer:
         #def call_get_requests(url, params=None, verify=True):
         #    return call_requests('GET', url, params, verify=verify)
 
-        url = BASE_API_URL + f'/analyticsapps/api/v7/tenants/{tenantId}/analysisrun/{analysis_run}/summary'
-        #res = call_requests('GET', url)
-        res = {
-            "analysisRun": {
-                "name": "test analysis run11",
-                "installedAppId": "INTG-b6313fb2-5196-4da5-9553-c934ed54g161595",
-                "triggeredBy": "USR0000000005",
-                "isSavedAnalysis": "true",
-            "analysis": {
-                "name": "analysis for run11",
-                "partnerName": "United Services",
-                "partnerId": "msp_3",
-                "createdBy": {
-                    "loginName": "uadmin",
-                    "id": 0,
-                    "version": 0,
-                    "uuid": "USR0000000005"
-                    },
-                "id": "analysis-7ffe7ffe-7526-481b-91a2-beef2d7535de",
-                "version": 0,
-                "createdTime": "2022-03-08T10:18:32+0000"
-        },
-            "analysisConfig": {
-                "scheduleType": "ONDEMAND",
-                "analysisPeriod": "SPECIFIC",
-                "startTime": "2022-02-05T00:00:00+0000",
-                "endTime": "2022-03-01T23:59:59+0000",
-                "fileFormat": "PDF"
-        },
-            "id": "analysisrun-ab8b4ca8-7b34-4746-998e-1cf4ebc5f0db",
-            "version": 0
-            },
-        "genStime": 1644019200000,
-        "genEtime": 1646179199000,
-        "startTime": "2022-02-05T00:00:00+0000",
-        "endTime": "2022-03-01T23:59:59+0000"
-        }
-        #if res == None or not res.ok:
-        #    logger.info('Get excel summary is failed')
+        url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/{integrationId}/runs/{analysis_run}/summary'
+        
+        res = call_requests('GET', url)
+        
+        if res == None or not res.ok:
+            logger.info('Get excel summary is failed')
         
         self.res = res
 
@@ -586,7 +554,7 @@ class ExcelRenderer:
 
         ws.add_chart(chart, chart_data['chart-position'])
 
-    def generate_summary(self, res):
+    def generate_summary(self, res, tenantId):
         """
         add summary sheet
         """
@@ -619,7 +587,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C6']
-        cell.value = res['analysisRun']['analysis']['partnerId']
+        cell.value = tenantId
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -631,9 +599,10 @@ class ExcelRenderer:
 
         cell = ws['C7']
         # params = self.analysis_run.params
-        start_date = res['analysisRun']['analysisConfig']['startTime']
-        end_date = res['analysisRun']['analysisConfig']['endTime']
-        cell.value = f'{start_date} - {end_date}'
+        start_date = res['genStime']
+        end_date = res['genEtime']
+        #cell.value = f'{start_date} - {end_date}'
+        cell.value = f"{datetime.fromtimestamp(start_date / 1000).strftime('%B %d %Y %H:%M:%S')} - {datetime.fromtimestamp(end_date / 1000).strftime('%B %d %Y %H:%M:%S')}"
         #cell.value = f'{start_date.strftime("%B %d, %Y")} - {end_date.strftime("%B %d, %Y")}'
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
@@ -650,7 +619,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C9']
-        cell.value = res['analysisRun']['analysis']['name']
+        cell.value = res['analysisRun']['id']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -743,7 +712,8 @@ class ExcelRenderer:
         :return: Workbook
         """
         res = self.res
-        self.generate_summary(res)
+        tenantId = self.tenantId
+        self.generate_summary(res, tenantId)
         # run_data = self.analysis_run.get_result().get('excel-data', {})
         run_data = self.analysis_run
         for sheet in run_data['sheets']:
