@@ -267,9 +267,9 @@ def generate_pdf(analysis_run):
 
 
 
-def generate_excel(analysis_run, orgId, file_name=None):
+def generate_excel(analysis_run, orgId, integrationId, file_name=None):
     try:
-        excel_renderer = ExcelRenderer(analysis_run, orgId)
+        excel_renderer = ExcelRenderer(analysis_run, orgId, integrationId)
         workbook = excel_renderer.render()
     except Exception as ex:
         raise ex
@@ -283,26 +283,28 @@ def generate_excel(analysis_run, orgId, file_name=None):
 
     return output
 
+    
 
-def update_results_url(json_result_url, gen_start_time, gen_completed_time, analysisRunId, CONFIGURE, tenantId, excel_result_url=None, pdf_result_url=None):
-    if CONFIGURE == 'test':
-        url = BASE_API_URL + f'/api/v2/tenants/client_53/resources/{analysisRunId}'
-        data={ 
-                "description" : json_result_url
-                # "csv_download_url" : excel_result_url,
-                # "pdf_download_url" : pdf_result_url,
-                # "rep_gen_start_time" : gen_start_time,
-                # "rep_gen_completed_time" : gen_completed_time
-             }
-    else:
-        url = BASE_API_URL + f'/analyticsapps/api/v7/tenants/{tenantId}/analysisrun/id/{analysisRunId}'
+def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, status=None):
+
+    url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/{integrationId}/runs/{analysisRunId}'
+    
+    if pdf_result_url == None:
         data={
+                "status" : status,
                 "resultUrl" : json_result_url,
-                "pdfDownloadUrl" : pdf_result_url,
-                "csvDownloadUrl" : excel_result_url,
+                "filePath" : excel_result_url,
                 "repGenStartTime" : gen_start_time,
                 "repGenEndTime" : gen_completed_time
-            }
+        }
+    else:
+        data={
+                "status" : status,
+                "resultUrl" : json_result_url,
+                "filePath" : pdf_result_url,
+                "repGenStartTime" : gen_start_time,
+                "repGenEndTime" : gen_completed_time
+        }
 
     res = call_post_requests(url , data=json.dumps(data), verify=False);
     logger.info('Database update response is %s', res)
@@ -336,12 +338,12 @@ def delete_excel_file(source_path):
 
 
 #Generate excel file
-def generate_excel_file(run_id, orgId):
+def generate_excel_file(run_id, orgId, integrationId):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
     reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
-    generate_excel(excel_data, orgId, filepath)
+    generate_excel(excel_data, orgId, integrationId, filepath)
     excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/excel/' + reportname
     
     excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
